# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.patch_model import PatchModel

class TestPatchModel(unittest.TestCase):
    """PatchModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchModel:
        """Test PatchModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchModel`
        """
        model = PatchModel()
        if include_optional:
            return PatchModel(
                name = '',
                description = '',
                dataset_ids = [
                    ''
                    ],
                tools = [
                    arthur_client.api_bindings.models.tool.Tool(
                        name = '', 
                        arguments = [
                            arthur_client.api_bindings.models.tool_argument.ToolArgument(
                                name = '', 
                                type = '', )
                            ], )
                    ],
                sub_agents = [
                    arthur_client.api_bindings.models.sub_agent.SubAgent(
                        name = '', )
                    ]
            )
        else:
            return PatchModel(
        )
        """

    def testPatchModel(self):
        """Test PatchModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
